# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class SMController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def create_network_sm_app_polaris(self,
                                      network_id,
                                      create_network_sm_app_polaris):
        """Does a POST request to /networks/{networkId}/sm/app/polaris.

        Create a new Polaris app

        Args:
            network_id (string): TODO: type description here. Example: 
            create_network_sm_app_polaris (CreateNetworkSmAppPolaris): TODO:
                type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/app/polaris'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_network_sm_app_polaris))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_app_polaris(self,
                                   network_id,
                                   bundle_id=None):
        """Does a GET request to /networks/{networkId}/sm/app/polaris.

        Get details for a Cisco Polaris app if it exists

        Args:
            network_id (string): TODO: type description here. Example: 
            bundle_id (string, optional): The bundle ID of the app to be
                found, defaults to com.cisco.ciscosecurity.app

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/app/polaris'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'bundleId': bundle_id
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_sm_app_polaris(self,
                                      network_id,
                                      app_id,
                                      update_network_sm_app_polaris=None):
        """Does a PUT request to /networks/{networkId}/sm/app/polaris/{appId}.

        Update an existing Polaris app

        Args:
            network_id (string): TODO: type description here. Example: 
            app_id (string): TODO: type description here. Example: 
            update_network_sm_app_polaris (UpdateNetworkSmAppPolaris,
                optional): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/app/polaris/{appId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'appId': app_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_sm_app_polaris))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def delete_network_sm_app_polaris(self,
                                      network_id,
                                      app_id):
        """Does a DELETE request to /networks/{networkId}/sm/app/polaris/{appId}.

        Delete a Cisco Polaris app

        Args:
            network_id (string): TODO: type description here. Example: 
            app_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/app/polaris/{appId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'appId': app_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_network_sm_bypass_activation_lock_attempt(self,
                                                         network_id,
                                                         create_network_sm_bypass_activation_lock_attempt):
        """Does a POST request to /networks/{networkId}/sm/bypassActivationLockAttempts.

        Bypass activation lock attempt

        Args:
            network_id (string): TODO: type description here. Example: 
            create_network_sm_bypass_activation_lock_attempt
                (CreateNetworkSmBypassActivationLockAttempt): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/bypassActivationLockAttempts'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_network_sm_bypass_activation_lock_attempt))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_bypass_activation_lock_attempt(self,
                                                      network_id,
                                                      attempt_id):
        """Does a GET request to /networks/{networkId}/sm/bypassActivationLockAttempts/{attemptId}.

        Bypass activation lock attempt status

        Args:
            network_id (string): TODO: type description here. Example: 
            attempt_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/bypassActivationLockAttempts/{attemptId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'attemptId': attempt_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_sm_device_fields(self,
                                        network_id,
                                        update_network_sm_device_fields):
        """Does a PUT request to /networks/{networkId}/sm/device/fields.

        Modify the fields of a device

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_sm_device_fields (UpdateNetworkSmDeviceFields):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/device/fields'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_sm_device_fields))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_wipe_network_sm_device(self,
                                      network_id,
                                      wipe_network_sm_device=None):
        """Does a PUT request to /networks/{networkId}/sm/device/wipe.

        Wipe a device

        Args:
            network_id (string): TODO: type description here. Example: 
            wipe_network_sm_device (WipeNetworkSmDevice, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/device/wipe'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(wipe_network_sm_device))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_refresh_network_sm_device_details(self,
                                                 network_id,
                                                 device_id):
        """Does a POST request to /networks/{networkId}/sm/device/{deviceId}/refreshDetails.

        Refresh the details of a device

        Args:
            network_id (string): TODO: type description here. Example: 
            device_id (string): TODO: type description here. Example: 

        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/device/{deviceId}/refreshDetails'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'deviceId': device_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.post(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

    def get_network_sm_devices(self,
                               network_id,
                               fields=None,
                               wifi_macs=None,
                               serials=None,
                               ids=None,
                               scope=None,
                               batch_size=None,
                               batch_token=None):
        """Does a GET request to /networks/{networkId}/sm/devices.

        List the devices enrolled in an SM network with various specified
        fields and filters

        Args:
            network_id (string): TODO: type description here. Example: 
            fields (string, optional): Additional fields that will be
                displayed for each device. Multiple fields can be passed in as
                comma separated values.     The default fields are: id, name,
                tags, ssid, wifiMac, osName, systemModel, uuid, and
                serialNumber. The additional fields are: ip,     systemType,
                availableDeviceCapacity, kioskAppName, biosVersion,
                lastConnected, missingAppsCount, userSuppliedAddress,
                location, lastUser,     ownerEmail, ownerUsername, publicIp,
                phoneNumber, diskInfoJson, deviceCapacity, isManaged, hadMdm,
                isSupervised, meid, imei, iccid,     simCarrierNetwork,
                cellularDataUsed, isHotspotEnabled, createdAt,
                batteryEstCharge, quarantined, avName, avRunning, asName,
                fwName,     isRooted, loginRequired, screenLockEnabled,
                screenLockDelay, autoLoginDisabled, autoTags, hasMdm,
                hasDesktopAgent, diskEncryptionEnabled,    
                hardwareEncryptionCaps, passCodeLock, usesHardwareKeystore,
                and androidSecurityPatchVersion.
            wifi_macs (string, optional): Filter devices by wifi mac(s).
                Multiple wifi macs can be passed in as comma separated
                values.
            serials (string, optional): Filter devices by serial(s). Multiple
                serials can be passed in as comma separated values.
            ids (string, optional): Filter devices by id(s). Multiple ids can
                be passed in as comma separated values.
            scope (string, optional): Specify a scope (one of all, none,
                withAny, withAll, withoutAny, or withoutAll) and a set of tags
                as comma separated values.
            batch_size (int, optional): Number of devices to return, 1000 is
                the default as well as the max.
            batch_token (string, optional): If the network has more devices
                than the batch size, a batch token will be returned     as a
                part of the device list. To see the remainder of the devices,
                pass in the batchToken as a parameter in the next request.    
                Requests made with the batchToken do not require additional
                parameters as the batchToken includes the parameters passed in
                with the original request. Additional parameters passed in
                with the batchToken will be ignored.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/devices'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'fields': fields,
            'wifiMacs': wifi_macs,
            'serials': serials,
            'ids': ids,
            'scope': scope,
            'batchSize': batch_size,
            'batchToken': batch_token
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_checkin_network_sm_devices(self,
                                          network_id,
                                          checkin_network_sm_devices=None):
        """Does a PUT request to /networks/{networkId}/sm/devices/checkin.

        Force check-in a set of devices

        Args:
            network_id (string): TODO: type description here. Example: 
            checkin_network_sm_devices (CheckinNetworkSmDevices, optional):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/devices/checkin'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(checkin_network_sm_devices))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_move_network_sm_devices(self,
                                       network_id,
                                       move_network_sm_devices):
        """Does a PUT request to /networks/{networkId}/sm/devices/move.

        Move a set of devices to a new network

        Args:
            network_id (string): TODO: type description here. Example: 
            move_network_sm_devices (MoveNetworkSmDevices): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/devices/move'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(move_network_sm_devices))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_sm_devices_tags(self,
                                       network_id,
                                       update_network_sm_devices_tags):
        """Does a PUT request to /networks/{networkId}/sm/devices/tags.

        Add, delete, or update the tags of a set of devices

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_sm_devices_tags (UpdateNetworkSmDevicesTags): TODO:
                type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/devices/tags'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_sm_devices_tags))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_unenroll_network_sm_device(self,
                                          network_id,
                                          device_id):
        """Does a POST request to /networks/{networkId}/sm/devices/{deviceId}/unenroll.

        Unenroll a device

        Args:
            network_id (string): TODO: type description here. Example: 
            device_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/devices/{deviceId}/unenroll'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'deviceId': device_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.post(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_network_sm_profile_clarity(self,
                                          network_id,
                                          create_network_sm_profile_clarity):
        """Does a POST request to /networks/{networkId}/sm/profile/clarity.

        Create a new profile containing a Cisco Clarity payload

        Args:
            network_id (string): TODO: type description here. Example: 
            create_network_sm_profile_clarity (CreateNetworkSmProfileClarity):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profile/clarity'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_network_sm_profile_clarity))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_sm_profile_clarity(self,
                                          network_id,
                                          profile_id,
                                          update_network_sm_profile_clarity=None):
        """Does a PUT request to /networks/{networkId}/sm/profile/clarity/{profileId}.

        Update an existing profile containing a Cisco Clarity payload

        Args:
            network_id (string): TODO: type description here. Example: 
            profile_id (string): TODO: type description here. Example: 
            update_network_sm_profile_clarity (UpdateNetworkSmProfileClarity,
                optional): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profile/clarity/{profileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'profileId': profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_sm_profile_clarity))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def add_network_sm_profile_clarity(self,
                                       network_id,
                                       profile_id,
                                       add_network_sm_profile_clarity):
        """Does a POST request to /networks/{networkId}/sm/profile/clarity/{profileId}.

        Add a Cisco Clarity payload to an existing profile

        Args:
            network_id (string): TODO: type description here. Example: 
            profile_id (string): TODO: type description here. Example: 
            add_network_sm_profile_clarity (AddNetworkSmProfileClarity): TODO:
                type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profile/clarity/{profileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'profileId': profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(add_network_sm_profile_clarity))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_profile_clarity(self,
                                       network_id,
                                       profile_id):
        """Does a GET request to /networks/{networkId}/sm/profile/clarity/{profileId}.

        Get details for a Cisco Clarity payload

        Args:
            network_id (string): TODO: type description here. Example: 
            profile_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profile/clarity/{profileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'profileId': profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def delete_network_sm_profile_clarity(self,
                                          network_id,
                                          profile_id):
        """Does a DELETE request to /networks/{networkId}/sm/profile/clarity/{profileId}.

        Delete a Cisco Clarity payload. Deletes the entire profile if it's
        empty after removing the payload.

        Args:
            network_id (string): TODO: type description here. Example: 
            profile_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profile/clarity/{profileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'profileId': profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_network_sm_profile_umbrella(self,
                                           network_id,
                                           create_network_sm_profile_umbrella):
        """Does a POST request to /networks/{networkId}/sm/profile/umbrella.

        Create a new profile containing a Cisco Umbrella payload

        Args:
            network_id (string): TODO: type description here. Example: 
            create_network_sm_profile_umbrella
                (CreateNetworkSmProfileUmbrella): TODO: type description here.
                Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profile/umbrella'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_network_sm_profile_umbrella))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_sm_profile_umbrella(self,
                                           network_id,
                                           profile_id,
                                           update_network_sm_profile_umbrella=None):
        """Does a PUT request to /networks/{networkId}/sm/profile/umbrella/{profileId}.

        Update an existing profile containing a Cisco Umbrella payload

        Args:
            network_id (string): TODO: type description here. Example: 
            profile_id (string): TODO: type description here. Example: 
            update_network_sm_profile_umbrella
                (UpdateNetworkSmProfileUmbrella, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profile/umbrella/{profileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'profileId': profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_sm_profile_umbrella))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def add_network_sm_profile_umbrella(self,
                                        network_id,
                                        profile_id,
                                        add_network_sm_profile_umbrella):
        """Does a POST request to /networks/{networkId}/sm/profile/umbrella/{profileId}.

        Add a Cisco Umbrella payload to an existing profile

        Args:
            network_id (string): TODO: type description here. Example: 
            profile_id (string): TODO: type description here. Example: 
            add_network_sm_profile_umbrella (AddNetworkSmProfileUmbrella):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profile/umbrella/{profileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'profileId': profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(add_network_sm_profile_umbrella))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_profile_umbrella(self,
                                        network_id,
                                        profile_id):
        """Does a GET request to /networks/{networkId}/sm/profile/umbrella/{profileId}.

        Get details for a Cisco Umbrella payload

        Args:
            network_id (string): TODO: type description here. Example: 
            profile_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profile/umbrella/{profileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'profileId': profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def delete_network_sm_profile_umbrella(self,
                                           network_id,
                                           profile_id):
        """Does a DELETE request to /networks/{networkId}/sm/profile/umbrella/{profileId}.

        Delete a Cisco Umbrella payload. Deletes the entire profile if it's
        empty after removing the payload

        Args:
            network_id (string): TODO: type description here. Example: 
            profile_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profile/umbrella/{profileId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'profileId': profile_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_profiles(self,
                                network_id):
        """Does a GET request to /networks/{networkId}/sm/profiles.

        List all the profiles in the network

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/profiles'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_user_device_profiles(self,
                                            network_id,
                                            user_id):
        """Does a GET request to /networks/{networkId}/sm/user/{userId}/deviceProfiles.

        Get the profiles associated with a user

        Args:
            network_id (string): TODO: type description here. Example: 
            user_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/user/{userId}/deviceProfiles'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'userId': user_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_user_softwares(self,
                                      network_id,
                                      user_id):
        """Does a GET request to /networks/{networkId}/sm/user/{userId}/softwares.

        Get a list of softwares associated with a user

        Args:
            network_id (string): TODO: type description here. Example: 
            user_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/user/{userId}/softwares'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'userId': user_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_users(self,
                             network_id,
                             ids=None,
                             usernames=None,
                             emails=None,
                             scope=None):
        """Does a GET request to /networks/{networkId}/sm/users.

        List the owners in an SM network with various specified fields and
        filters

        Args:
            network_id (string): TODO: type description here. Example: 
            ids (string, optional): Filter users by id(s). Multiple ids can be
                passed in as comma separated values.
            usernames (string, optional): Filter users by username(s).
                Multiple usernames can be passed in as comma separated
                values.
            emails (string, optional): Filter users by email(s). Multiple
                emails can be passed in as comma separated values.
            scope (string, optional): Specifiy a scope (one of all, none,
                withAny, withAll, withoutAny, withoutAll) and a set of tags as
                comma separated values.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/users'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'ids': ids,
            'usernames': usernames,
            'emails': emails,
            'scope': scope
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_cellular_usage_history(self,
                                              network_id,
                                              device_id):
        """Does a GET request to /networks/{networkId}/sm/{deviceId}/cellularUsageHistory.

        Return the client's daily cellular data usage history. Usage data is
        in kilobytes.

        Args:
            network_id (string): TODO: type description here. Example: 
            device_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/{deviceId}/cellularUsageHistory'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'deviceId': device_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_certs(self,
                             network_id,
                             device_id):
        """Does a GET request to /networks/{networkId}/sm/{deviceId}/certs.

        List the certs on a device

        Args:
            network_id (string): TODO: type description here. Example: 
            device_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/{deviceId}/certs'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'deviceId': device_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_device_profiles(self,
                                       network_id,
                                       device_id):
        """Does a GET request to /networks/{networkId}/sm/{deviceId}/deviceProfiles.

        Get the profiles associated with a device

        Args:
            network_id (string): TODO: type description here. Example: 
            device_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/{deviceId}/deviceProfiles'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'deviceId': device_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_network_adapters(self,
                                        network_id,
                                        device_id):
        """Does a GET request to /networks/{networkId}/sm/{deviceId}/networkAdapters.

        List the network adapters of a device

        Args:
            network_id (string): TODO: type description here. Example: 
            device_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/{deviceId}/networkAdapters'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'deviceId': device_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_restrictions(self,
                                    network_id,
                                    device_id):
        """Does a GET request to /networks/{networkId}/sm/{deviceId}/restrictions.

        List the restrictions on a device

        Args:
            network_id (string): TODO: type description here. Example: 
            device_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/{deviceId}/restrictions'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'deviceId': device_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_security_centers(self,
                                        network_id,
                                        device_id):
        """Does a GET request to /networks/{networkId}/sm/{deviceId}/securityCenters.

        List the security centers on a device

        Args:
            network_id (string): TODO: type description here. Example: 
            device_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/{deviceId}/securityCenters'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'deviceId': device_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_softwares(self,
                                 network_id,
                                 device_id):
        """Does a GET request to /networks/{networkId}/sm/{deviceId}/softwares.

        Get a list of softwares associated with a device

        Args:
            network_id (string): TODO: type description here. Example: 
            device_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/{deviceId}/softwares'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'deviceId': device_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_wlan_lists(self,
                                  network_id,
                                  device_id):
        """Does a GET request to /networks/{networkId}/sm/{deviceId}/wlanLists.

        List the saved SSID names on a device

        Args:
            network_id (string): TODO: type description here. Example: 
            device_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/{deviceId}/wlanLists'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'deviceId': device_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_lock_network_sm_devices(self,
                                       network_id,
                                       lock_network_sm_devices=None):
        """Does a PUT request to /networks/{network_id}/sm/devices/lock.

        Lock a set of devices

        Args:
            network_id (string): TODO: type description here. Example: 
            lock_network_sm_devices (LockNetworkSmDevices, optional): TODO:
                type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{network_id}/sm/devices/lock'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'network_id': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(lock_network_sm_devices))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_connectivity(self,
                                    network_id,
                                    id,
                                    per_page=None,
                                    starting_after=None,
                                    ending_before=None):
        """Does a GET request to /networks/{network_id}/sm/{id}/connectivity.

        Returns historical connectivity data (whether a device is regularly
        checking in to Dashboard).

        Args:
            network_id (string): TODO: type description here. Example: 
            id (string): TODO: type description here. Example: 
            per_page (string, optional): The number of entries per page
                returned
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, next or prev page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, next or prev page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{network_id}/sm/{id}/connectivity'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'network_id': network_id,
            'id': id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_desktop_logs(self,
                                    network_id,
                                    id,
                                    per_page=None,
                                    starting_after=None,
                                    ending_before=None):
        """Does a GET request to /networks/{network_id}/sm/{id}/desktopLogs.

        Return historical records of various Systems Manager network
        connection details for desktop devices.

        Args:
            network_id (string): TODO: type description here. Example: 
            id (string): TODO: type description here. Example: 
            per_page (string, optional): The number of entries per page
                returned
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, next or prev page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, next or prev page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{network_id}/sm/{id}/desktopLogs'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'network_id': network_id,
            'id': id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_device_command_logs(self,
                                           network_id,
                                           id,
                                           per_page=None,
                                           starting_after=None,
                                           ending_before=None):
        """Does a GET request to /networks/{network_id}/sm/{id}/deviceCommandLogs.

            Return historical records of commands sent to Systems Manager
            devices.
            <p>Note that this will include the name of the Dashboard user who
            initiated the command if it was generated
            by a Dashboard admin rather than the automatic behavior of the
            system; you may wish to filter this out
            of any reports.</p>

        Args:
            network_id (string): TODO: type description here. Example: 
            id (string): TODO: type description here. Example: 
            per_page (string, optional): The number of entries per page
                returned
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, next or prev page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, next or prev page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{network_id}/sm/{id}/deviceCommandLogs'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'network_id': network_id,
            'id': id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_performance_history(self,
                                           network_id,
                                           id,
                                           per_page=None,
                                           starting_after=None,
                                           ending_before=None):
        """Does a GET request to /networks/{network_id}/sm/{id}/performanceHistory.

        Return historical records of various Systems Manager client metrics
        for desktop devices.

        Args:
            network_id (string): TODO: type description here. Example: 
            id (string): TODO: type description here. Example: 
            per_page (string, optional): The number of entries per page
                returned
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, next or prev page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, next or prev page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{network_id}/sm/{id}/performanceHistory'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'network_id': network_id,
            'id': id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class AdminSettings(object):

    """Implementation of the 'AdminSettings' model.

    Settings for describing which kinds of admins this policy applies to.

    Attributes:
        applies_to (AppliesToEnum): Which kinds of admins this policy applies
            to. Can be one of 'All organization admins', 'All enterprise
            admins', 'All network admins', 'All admins of networks...', 'All
            admins of networks tagged...', 'Specific admins...', 'All admins'
            or 'All SAML admins'.
        values (list of string): If 'appliesTo' is set to one of 'Specific
            admins...', 'All admins of networks...' or 'All admins of networks
            tagged...', then you must specify this 'values' property to
            provide the set of     entities to apply the branding policy to.
            For 'Specific admins...', specify an array of admin IDs. For 'All
            admins of     networks...', specify an array of network IDs and/or
            configuration template IDs. For 'All admins of networks
            tagged...',     specify an array of tag names.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "applies_to":'appliesTo',
        "values":'values'
    }

    def __init__(self,
                 applies_to=None,
                 values=None):
        """Constructor for the AdminSettings class"""

        # Initialize members of the class
        self.applies_to = applies_to
        self.values = values


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        applies_to = dictionary.get('appliesTo')
        values = dictionary.get('values')

        # Return an object of this model
        return cls(applies_to,
                   values)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.decorators import lazy_property
from test_meraki.configuration import Configuration
from test_meraki.controllers.api_usage_controller import APIUsageController
from test_meraki.controllers.action_batches_controller import ActionBatchesController
from test_meraki.controllers.admins_controller import AdminsController
from test_meraki.controllers.alert_settings_controller import AlertSettingsController
from test_meraki.controllers.bluetooth_clients_controller import BluetoothClientsController
from test_meraki.controllers.cameras_controller import CamerasController
from test_meraki.controllers.clients_controller import ClientsController
from test_meraki.controllers.config_templates_controller import ConfigTemplatesController
from test_meraki.controllers.connectivity_monitoring_destinations_controller import ConnectivityMonitoringDestinationsController
from test_meraki.controllers.content_filtering_categories_controller import ContentFilteringCategoriesController
from test_meraki.controllers.content_filtering_rules_controller import ContentFilteringRulesController
from test_meraki.controllers.dashboard_branding_policies_controller import DashboardBrandingPoliciesController
from test_meraki.controllers.devices_controller import DevicesController
from test_meraki.controllers.events_controller import EventsController
from test_meraki.controllers.firewalled_services_controller import FirewalledServicesController
from test_meraki.controllers.floorplans_controller import FloorplansController
from test_meraki.controllers.group_policies_controller import GroupPoliciesController
from test_meraki.controllers.http_servers_controller import HTTPServersController
from test_meraki.controllers.intrusion_settings_controller import IntrusionSettingsController
from test_meraki.controllers.licenses_controller import LicensesController
from test_meraki.controllers.mrl_3_firewall_controller import MRL3FirewallController
from test_meraki.controllers.mv_sense_controller import MVSenseController
from test_meraki.controllers.mx_11_nat_rules_controller import MX11NATRulesController
from test_meraki.controllers.mx_1_many_nat_rules_controller import MX1ManyNATRulesController
from test_meraki.controllers.mxl_3_firewall_controller import MXL3FirewallController
from test_meraki.controllers.mxl_7_application_categories_controller import MXL7ApplicationCategoriesController
from test_meraki.controllers.mxl_7_firewall_controller import MXL7FirewallController
from test_meraki.controllers.mxvlan_ports_controller import MXVLANPortsController
from test_meraki.controllers.mxvpn_firewall_controller import MXVPNFirewallController
from test_meraki.controllers.mx_cellular_firewall_controller import MXCellularFirewallController
from test_meraki.controllers.mx_port_forwarding_rules_controller import MXPortForwardingRulesController
from test_meraki.controllers.mx_static_routes_controller import MXStaticRoutesController
from test_meraki.controllers.mx_warm_spare_settings_controller import MXWarmSpareSettingsController
from test_meraki.controllers.malware_settings_controller import MalwareSettingsController
from test_meraki.controllers.management_interface_settings_controller import ManagementInterfaceSettingsController
from test_meraki.controllers.meraki_auth_users_controller import MerakiAuthUsersController
from test_meraki.controllers.named_tag_scope_controller import NamedTagScopeController
from test_meraki.controllers.net_flow_settings_controller import NetFlowSettingsController
from test_meraki.controllers.networks_controller import NetworksController
from test_meraki.controllers.open_api_spec_controller import OpenAPISpecController
from test_meraki.controllers.organizations_controller import OrganizationsController
from test_meraki.controllers.pii_controller import PIIController
from test_meraki.controllers.radio_settings_controller import RadioSettingsController
from test_meraki.controllers.saml_roles_controller import SAMLRolesController
from test_meraki.controllers.sm_controller import SMController
from test_meraki.controllers.snmp_settings_controller import SNMPSettingsController
from test_meraki.controllers.ssi_ds_controller import SSIDsController
from test_meraki.controllers.security_events_controller import SecurityEventsController
from test_meraki.controllers.splash_login_attempts_controller import SplashLoginAttemptsController
from test_meraki.controllers.splash_settings_controller import SplashSettingsController
from test_meraki.controllers.switch_ac_ls_controller import SwitchACLsController
from test_meraki.controllers.switch_port_schedules_controller import SwitchPortSchedulesController
from test_meraki.controllers.switch_ports_controller import SwitchPortsController
from test_meraki.controllers.switch_profiles_controller import SwitchProfilesController
from test_meraki.controllers.switch_settings_controller import SwitchSettingsController
from test_meraki.controllers.switch_stacks_controller import SwitchStacksController
from test_meraki.controllers.syslog_servers_controller import SyslogServersController
from test_meraki.controllers.traffic_analysis_settings_controller import TrafficAnalysisSettingsController
from test_meraki.controllers.traffic_shaping_controller import TrafficShapingController
from test_meraki.controllers.uplink_settings_controller import UplinkSettingsController
from test_meraki.controllers.vla_ns_controller import VLANsController
from test_meraki.controllers.webhook_logs_controller import WebhookLogsController
from test_meraki.controllers.wireless_health_controller import WirelessHealthController
from test_meraki.controllers.wireless_settings_controller import WirelessSettingsController


class TestMerakiClient(object):

    config = Configuration

    @lazy_property
    def api_usage(self):
        return APIUsageController()

    @lazy_property
    def action_batches(self):
        return ActionBatchesController()

    @lazy_property
    def admins(self):
        return AdminsController()

    @lazy_property
    def alert_settings(self):
        return AlertSettingsController()

    @lazy_property
    def bluetooth_clients(self):
        return BluetoothClientsController()

    @lazy_property
    def cameras(self):
        return CamerasController()

    @lazy_property
    def clients(self):
        return ClientsController()

    @lazy_property
    def config_templates(self):
        return ConfigTemplatesController()

    @lazy_property
    def connectivity_monitoring_destinations(self):
        return ConnectivityMonitoringDestinationsController()

    @lazy_property
    def content_filtering_categories(self):
        return ContentFilteringCategoriesController()

    @lazy_property
    def content_filtering_rules(self):
        return ContentFilteringRulesController()

    @lazy_property
    def dashboard_branding_policies(self):
        return DashboardBrandingPoliciesController()

    @lazy_property
    def devices(self):
        return DevicesController()

    @lazy_property
    def events(self):
        return EventsController()

    @lazy_property
    def firewalled_services(self):
        return FirewalledServicesController()

    @lazy_property
    def floorplans(self):
        return FloorplansController()

    @lazy_property
    def group_policies(self):
        return GroupPoliciesController()

    @lazy_property
    def http_servers(self):
        return HTTPServersController()

    @lazy_property
    def intrusion_settings(self):
        return IntrusionSettingsController()

    @lazy_property
    def licenses(self):
        return LicensesController()

    @lazy_property
    def mr_l_3_firewall(self):
        return MRL3FirewallController()

    @lazy_property
    def mv_sense(self):
        return MVSenseController()

    @lazy_property
    def mx_1_1_nat_rules(self):
        return MX11NATRulesController()

    @lazy_property
    def mx_1_many_nat_rules(self):
        return MX1ManyNATRulesController()

    @lazy_property
    def mx_l_3_firewall(self):
        return MXL3FirewallController()

    @lazy_property
    def mx_l_7_application_categories(self):
        return MXL7ApplicationCategoriesController()

    @lazy_property
    def mx_l_7_firewall(self):
        return MXL7FirewallController()

    @lazy_property
    def mx_vlan_ports(self):
        return MXVLANPortsController()

    @lazy_property
    def mx_vpn_firewall(self):
        return MXVPNFirewallController()

    @lazy_property
    def mx_cellular_firewall(self):
        return MXCellularFirewallController()

    @lazy_property
    def mx_port_forwarding_rules(self):
        return MXPortForwardingRulesController()

    @lazy_property
    def mx_static_routes(self):
        return MXStaticRoutesController()

    @lazy_property
    def mx_warm_spare_settings(self):
        return MXWarmSpareSettingsController()

    @lazy_property
    def malware_settings(self):
        return MalwareSettingsController()

    @lazy_property
    def management_interface_settings(self):
        return ManagementInterfaceSettingsController()

    @lazy_property
    def meraki_auth_users(self):
        return MerakiAuthUsersController()

    @lazy_property
    def named_tag_scope(self):
        return NamedTagScopeController()

    @lazy_property
    def net_flow_settings(self):
        return NetFlowSettingsController()

    @lazy_property
    def networks(self):
        return NetworksController()

    @lazy_property
    def open_api_spec(self):
        return OpenAPISpecController()

    @lazy_property
    def organizations(self):
        return OrganizationsController()

    @lazy_property
    def pii(self):
        return PIIController()

    @lazy_property
    def radio_settings(self):
        return RadioSettingsController()

    @lazy_property
    def saml_roles(self):
        return SAMLRolesController()

    @lazy_property
    def sm(self):
        return SMController()

    @lazy_property
    def snmp_settings(self):
        return SNMPSettingsController()

    @lazy_property
    def ssi_ds(self):
        return SSIDsController()

    @lazy_property
    def security_events(self):
        return SecurityEventsController()

    @lazy_property
    def splash_login_attempts(self):
        return SplashLoginAttemptsController()

    @lazy_property
    def splash_settings(self):
        return SplashSettingsController()

    @lazy_property
    def switch_ac_ls(self):
        return SwitchACLsController()

    @lazy_property
    def switch_port_schedules(self):
        return SwitchPortSchedulesController()

    @lazy_property
    def switch_ports(self):
        return SwitchPortsController()

    @lazy_property
    def switch_profiles(self):
        return SwitchProfilesController()

    @lazy_property
    def switch_settings(self):
        return SwitchSettingsController()

    @lazy_property
    def switch_stacks(self):
        return SwitchStacksController()

    @lazy_property
    def syslog_servers(self):
        return SyslogServersController()

    @lazy_property
    def traffic_analysis_settings(self):
        return TrafficAnalysisSettingsController()

    @lazy_property
    def traffic_shaping(self):
        return TrafficShapingController()

    @lazy_property
    def uplink_settings(self):
        return UplinkSettingsController()

    @lazy_property
    def vla_ns(self):
        return VLANsController()

    @lazy_property
    def webhook_logs(self):
        return WebhookLogsController()

    @lazy_property
    def wireless_health(self):
        return WirelessHealthController()

    @lazy_property
    def wireless_settings(self):
        return WirelessSettingsController()


    def __init__(self,
                 x_cisco_meraki_api_key=None):
        if x_cisco_meraki_api_key is not None:
            Configuration.x_cisco_meraki_api_key = x_cisco_meraki_api_key




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class V3PrivModeEnum(object):

    """Implementation of the 'V3PrivMode' enum.

    The SNMP version 3 privacy mode. Can be either 'DES' or 'AES128'.

    Attributes:
        DES: TODO: type description here.
        AES128: TODO: type description here.

    """

    DES = 'DES'

    AES128 = 'AES128'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateDeviceSwitchPort(object):

    """Implementation of the 'updateDeviceSwitchPort' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the switch port
        tags (string): The tags of the switch port
        enabled (bool): The status of the switch port
        mtype (string): The type of the switch port ("access" or "trunk")
        vlan (int): The VLAN of the switch port. A null value will clear the
            value set for trunk ports.
        voice_vlan (int): The voice VLAN of the switch port. Only applicable
            to access ports.
        allowed_vlans (string): The VLANs allowed on the switch port. Only
            applicable to trunk ports.
        poe_enabled (bool): The PoE status of the switch port
        isolation_enabled (bool): The isolation status of the switch port
        rstp_enabled (bool): The rapid spanning tree protocol status
        stp_guard (string): The state of the STP guard ("disabled", "Root
            guard", "BPDU guard", "Loop guard")
        access_policy_number (int): The number of the access policy of the
            switch port. Only applicable to access ports.
        link_negotiation (string): The link speed for the switch port
        port_schedule_id (string): The ID of the port schedule. A value of
            null will clear the port schedule.
        udld (UdldEnum): The action to take when Unidirectional Link is
            detected (Alert only, Enforce). Default configuration is Alert
            only.
        mac_whitelist (list of string): Only devices with MAC addresses
            specified in this list will have access to this port. Up to 20 MAC
            addresses can be defined. To disable MAC whitelist, set
            accessPolicyNumber to null.
        sticky_mac_whitelist (list of string): The initial list of MAC
            addresses for sticky Mac whitelist. To reset Sticky MAC whitelist,
            set accessPolicyNumber to null.
        sticky_mac_whitelist_limit (int): The maximum number of MAC addresses
            for sticky MAC whitelist.
        storm_control_enabled (bool): The storm control status of the switch
            port

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "tags":'tags',
        "enabled":'enabled',
        "mtype":'type',
        "vlan":'vlan',
        "voice_vlan":'voiceVlan',
        "allowed_vlans":'allowedVlans',
        "poe_enabled":'poeEnabled',
        "isolation_enabled":'isolationEnabled',
        "rstp_enabled":'rstpEnabled',
        "stp_guard":'stpGuard',
        "access_policy_number":'accessPolicyNumber',
        "link_negotiation":'linkNegotiation',
        "port_schedule_id":'portScheduleId',
        "udld":'udld',
        "mac_whitelist":'macWhitelist',
        "sticky_mac_whitelist":'stickyMacWhitelist',
        "sticky_mac_whitelist_limit":'stickyMacWhitelistLimit',
        "storm_control_enabled":'stormControlEnabled'
    }

    def __init__(self,
                 name=None,
                 tags=None,
                 enabled=None,
                 mtype=None,
                 vlan=None,
                 voice_vlan=None,
                 allowed_vlans=None,
                 poe_enabled=None,
                 isolation_enabled=None,
                 rstp_enabled=None,
                 stp_guard=None,
                 access_policy_number=None,
                 link_negotiation=None,
                 port_schedule_id=None,
                 udld=None,
                 mac_whitelist=None,
                 sticky_mac_whitelist=None,
                 sticky_mac_whitelist_limit=None,
                 storm_control_enabled=None):
        """Constructor for the UpdateDeviceSwitchPort class"""

        # Initialize members of the class
        self.name = name
        self.tags = tags
        self.enabled = enabled
        self.mtype = mtype
        self.vlan = vlan
        self.voice_vlan = voice_vlan
        self.allowed_vlans = allowed_vlans
        self.poe_enabled = poe_enabled
        self.isolation_enabled = isolation_enabled
        self.rstp_enabled = rstp_enabled
        self.stp_guard = stp_guard
        self.access_policy_number = access_policy_number
        self.link_negotiation = link_negotiation
        self.port_schedule_id = port_schedule_id
        self.udld = udld
        self.mac_whitelist = mac_whitelist
        self.sticky_mac_whitelist = sticky_mac_whitelist
        self.sticky_mac_whitelist_limit = sticky_mac_whitelist_limit
        self.storm_control_enabled = storm_control_enabled


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        tags = dictionary.get('tags')
        enabled = dictionary.get('enabled')
        mtype = dictionary.get('type')
        vlan = dictionary.get('vlan')
        voice_vlan = dictionary.get('voiceVlan')
        allowed_vlans = dictionary.get('allowedVlans')
        poe_enabled = dictionary.get('poeEnabled')
        isolation_enabled = dictionary.get('isolationEnabled')
        rstp_enabled = dictionary.get('rstpEnabled')
        stp_guard = dictionary.get('stpGuard')
        access_policy_number = dictionary.get('accessPolicyNumber')
        link_negotiation = dictionary.get('linkNegotiation')
        port_schedule_id = dictionary.get('portScheduleId')
        udld = dictionary.get('udld')
        mac_whitelist = dictionary.get('macWhitelist')
        sticky_mac_whitelist = dictionary.get('stickyMacWhitelist')
        sticky_mac_whitelist_limit = dictionary.get('stickyMacWhitelistLimit')
        storm_control_enabled = dictionary.get('stormControlEnabled')

        # Return an object of this model
        return cls(name,
                   tags,
                   enabled,
                   mtype,
                   vlan,
                   voice_vlan,
                   allowed_vlans,
                   poe_enabled,
                   isolation_enabled,
                   rstp_enabled,
                   stp_guard,
                   access_policy_number,
                   link_negotiation,
                   port_schedule_id,
                   udld,
                   mac_whitelist,
                   sticky_mac_whitelist,
                   sticky_mac_whitelist_limit,
                   storm_control_enabled)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.vendor_config

class AddNetworkSmProfileClarity(object):

    """Implementation of the 'addNetworkSmProfileClarity' model.

    TODO: type model description here.

    Attributes:
        plugin_bundle_id (string): The bundle ID of the application, defaults
            to com.cisco.ciscosecurity.app
        filter_browsers (bool): Whether or not to enable browser traffic
            filtering (one of true, false). Defaults to true
        filter_sockets (bool): Whether or not to enable socket traffic
            filtering (one of true, false). Defaults to true
        vendor_config (list of VendorConfig): The specific VendorConfig to be
            passed to the filtering framework, in the form of an array of
            objects (as JSON).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "vendor_config":'VendorConfig',
        "plugin_bundle_id":'PluginBundleID',
        "filter_browsers":'FilterBrowsers',
        "filter_sockets":'FilterSockets'
    }

    def __init__(self,
                 vendor_config=None,
                 plugin_bundle_id=None,
                 filter_browsers=None,
                 filter_sockets=None):
        """Constructor for the AddNetworkSmProfileClarity class"""

        # Initialize members of the class
        self.plugin_bundle_id = plugin_bundle_id
        self.filter_browsers = filter_browsers
        self.filter_sockets = filter_sockets
        self.vendor_config = vendor_config


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        vendor_config = None
        if dictionary.get('VendorConfig') != None:
            vendor_config = list()
            for structure in dictionary.get('VendorConfig'):
                vendor_config.append(test_meraki.models.vendor_config.VendorConfig.from_dictionary(structure))
        plugin_bundle_id = dictionary.get('PluginBundleID')
        filter_browsers = dictionary.get('FilterBrowsers')
        filter_sockets = dictionary.get('FilterSockets')

        # Return an object of this model
        return cls(vendor_config,
                   plugin_bundle_id,
                   filter_browsers,
                   filter_sockets)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.tag_2
import test_meraki.models.network_2

class CreateOrganizationSamlRole(object):

    """Implementation of the 'createOrganizationSamlRole' model.

    TODO: type model description here.

    Attributes:
        role (string): The role of the SAML administrator
        org_access (string): The privilege of the SAML administrator on the
            organization
        tags (list of Tag2): The list of tags that the SAML administrator has
            privleges on
        networks (list of Network2): The list of networks that the SAML
            administrator has privileges on

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "role":'role',
        "org_access":'orgAccess',
        "tags":'tags',
        "networks":'networks'
    }

    def __init__(self,
                 role=None,
                 org_access=None,
                 tags=None,
                 networks=None):
        """Constructor for the CreateOrganizationSamlRole class"""

        # Initialize members of the class
        self.role = role
        self.org_access = org_access
        self.tags = tags
        self.networks = networks


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        role = dictionary.get('role')
        org_access = dictionary.get('orgAccess')
        tags = None
        if dictionary.get('tags') != None:
            tags = list()
            for structure in dictionary.get('tags'):
                tags.append(test_meraki.models.tag_2.Tag2.from_dictionary(structure))
        networks = None
        if dictionary.get('networks') != None:
            networks = list()
            for structure in dictionary.get('networks'):
                networks.append(test_meraki.models.network_2.Network2.from_dictionary(structure))

        # Return an object of this model
        return cls(role,
                   org_access,
                   tags,
                   networks)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class PowerTypeEnum(object):

    """Implementation of the 'PowerType' enum.

    Per switch exception (combined, redundant, useNetworkSetting)

    Attributes:
        COMBINED: TODO: type description here.
        REDUNDANT: TODO: type description here.
        USENETWORKSETTING: TODO: type description here.

    """

    COMBINED = 'combined'

    REDUNDANT = 'redundant'

    USENETWORKSETTING = 'useNetworkSetting'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkDevice(object):

    """Implementation of the 'updateNetworkDevice' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of a device
        tags (string): The tags of a device
        lat (float): The latitude of a device
        lng (float): The longitude of a device
        address (string): The address of a device
        notes (string): The notes for the device. String. Limited to 255
            characters.
        move_map_marker (bool): Whether or not to set the latitude and
            longitude of a device based on the new address. Only applies when
            lat and lng are not specified.
        switch_profile_id (string): The ID of a switch profile to bind to the
            device (for available switch profiles, see the 'Switch Profiles'
            endpoint). Use null to unbind the switch device from the current
            profile. For a device to be bindable to a switch profile, it must
            (1) be a switch, and (2) belong to a network that is bound to a
            configuration template.
        floor_plan_id (string): The floor plan to associate to this device.
            null disassociates the device from the floorplan.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "tags":'tags',
        "lat":'lat',
        "lng":'lng',
        "address":'address',
        "notes":'notes',
        "move_map_marker":'moveMapMarker',
        "switch_profile_id":'switchProfileId',
        "floor_plan_id":'floorPlanId'
    }

    def __init__(self,
                 name=None,
                 tags=None,
                 lat=None,
                 lng=None,
                 address=None,
                 notes=None,
                 move_map_marker=None,
                 switch_profile_id=None,
                 floor_plan_id=None):
        """Constructor for the UpdateNetworkDevice class"""

        # Initialize members of the class
        self.name = name
        self.tags = tags
        self.lat = lat
        self.lng = lng
        self.address = address
        self.notes = notes
        self.move_map_marker = move_map_marker
        self.switch_profile_id = switch_profile_id
        self.floor_plan_id = floor_plan_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        tags = dictionary.get('tags')
        lat = dictionary.get('lat')
        lng = dictionary.get('lng')
        address = dictionary.get('address')
        notes = dictionary.get('notes')
        move_map_marker = dictionary.get('moveMapMarker')
        switch_profile_id = dictionary.get('switchProfileId')
        floor_plan_id = dictionary.get('floorPlanId')

        # Return an object of this model
        return cls(name,
                   tags,
                   lat,
                   lng,
                   address,
                   notes,
                   move_map_marker,
                   switch_profile_id,
                   floor_plan_id)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class DhcpHandlingEnum(object):

    """Implementation of the 'DhcpHandling' enum.

    The appliance's handling of DHCP requests on this VLAN. One of: 'Run a
    DHCP server', 'Relay DHCP to another server' or 'Do not respond to DHCP
    requests'

    Attributes:
        ENUM_RUN A DHCP SERVER: TODO: type description here.
        ENUM_RELAY DHCP TO ANOTHER SERVER: TODO: type description here.
        ENUM_DO NOT RESPOND TO DHCP REQUESTS: TODO: type description here.

    """

    ENUM_RUN_A_DHCP_SERVER = 'Run a DHCP server'

    ENUM_RELAY_DHCP_TO_ANOTHER_SERVER = 'Relay DHCP to another server'

    ENUM_DO_NOT_RESPOND_TO_DHCP_REQUESTS = 'Do not respond to DHCP requests'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateOrganizationBrandingPoliciesPriorities(object):

    """Implementation of the 'updateOrganizationBrandingPoliciesPriorities' model.

    TODO: type model description here.

    Attributes:
        branding_policy_ids (list of string): A list of branding policy IDs
            arranged in ascending priority order (IDs later in the array have
            higher priority).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "branding_policy_ids":'brandingPolicyIds'
    }

    def __init__(self,
                 branding_policy_ids=None):
        """Constructor for the UpdateOrganizationBrandingPoliciesPriorities class"""

        # Initialize members of the class
        self.branding_policy_ids = branding_policy_ids


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        branding_policy_ids = dictionary.get('brandingPolicyIds')

        # Return an object of this model
        return cls(branding_policy_ids)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class HelpTabEnum(object):

    """Implementation of the 'HelpTab' enum.

    The Help tab, under which all support information resides. If this tab is
    hidden, no other 'Help' branding
        customizations will be visible. Can be one of 'default or inherit',
        'hide' or 'show'.

    Attributes:
        ENUM_DEFAULT OR INHERIT: TODO: type description here.
        HIDE: TODO: type description here.
        SHOW: TODO: type description here.

    """

    ENUM_DEFAULT_OR_INHERIT = 'default or inherit'

    HIDE = 'hide'

    SHOW = 'show'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkBluetoothSettings(object):

    """Implementation of the 'updateNetworkBluetoothSettings' model.

    TODO: type model description here.

    Attributes:
        scanning_enabled (bool): Whether APs will scan for Bluetooth enabled
            clients. (true, false)
        advertising_enabled (bool): Whether APs will advertise beacons. (true,
            false)
        uuid (string): The UUID to be used in the beacon identifier.
        major_minor_assignment_mode (MajorMinorAssignmentModeEnum): The way
            major and minor number should be assigned to nodes in the network.
            ('Unique', 'Non-unique')
        major (int): The major number to be used in the beacon identifier.
            Only valid in 'Non-unique' mode.
        minor (int): The minor number to be used in the beacon identifier.
            Only valid in 'Non-unique' mode.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "scanning_enabled":'scanningEnabled',
        "advertising_enabled":'advertisingEnabled',
        "uuid":'uuid',
        "major_minor_assignment_mode":'majorMinorAssignmentMode',
        "major":'major',
        "minor":'minor'
    }

    def __init__(self,
                 scanning_enabled=None,
                 advertising_enabled=None,
                 uuid=None,
                 major_minor_assignment_mode=None,
                 major=None,
                 minor=None):
        """Constructor for the UpdateNetworkBluetoothSettings class"""

        # Initialize members of the class
        self.scanning_enabled = scanning_enabled
        self.advertising_enabled = advertising_enabled
        self.uuid = uuid
        self.major_minor_assignment_mode = major_minor_assignment_mode
        self.major = major
        self.minor = minor


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        scanning_enabled = dictionary.get('scanningEnabled')
        advertising_enabled = dictionary.get('advertisingEnabled')
        uuid = dictionary.get('uuid')
        major_minor_assignment_mode = dictionary.get('majorMinorAssignmentMode')
        major = dictionary.get('major')
        minor = dictionary.get('minor')

        # Return an object of this model
        return cls(scanning_enabled,
                   advertising_enabled,
                   uuid,
                   major_minor_assignment_mode,
                   major,
                   minor)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkSwitchSettingsQosRulesOrder(object):

    """Implementation of the 'updateNetworkSwitchSettingsQosRulesOrder' model.

    TODO: type model description here.

    Attributes:
        rule_ids (list of string): A list of quality of service rule IDs
            arranged in order in which they should be processed by the
            switch.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "rule_ids":'ruleIds'
    }

    def __init__(self,
                 rule_ids=None):
        """Constructor for the UpdateNetworkSwitchSettingsQosRulesOrder class"""

        # Initialize members of the class
        self.rule_ids = rule_ids


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        rule_ids = dictionary.get('ruleIds')

        # Return an object of this model
        return cls(rule_ids)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.traffic_shaping_rule
import test_meraki.models.l_3_firewall_rule
import test_meraki.models.l_7_firewall_rule

class FirewallAndTrafficShaping(object):

    """Implementation of the 'FirewallAndTrafficShaping' model.

    The firewall and traffic shaping rules and settings for your policy.

    Attributes:
        settings (Settings1Enum): How firewall and traffic shaping rules are
            enforced. Can be 'network default', 'ignore' or 'custom'.
        traffic_shaping_rules (list of TrafficShapingRule): An array of
            traffic shaping rules. Rules are applied in the order that    
            they are specified in. An empty list (or null) means no rules.
            Note that     you are allowed a maximum of 8 rules.
        l_3_firewall_rules (list of L3FirewallRule): An ordered array of the
            L3 firewall rules
        l_7_firewall_rules (list of L7FirewallRule): An ordered array of L7
            firewall rules

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "settings":'settings',
        "traffic_shaping_rules":'trafficShapingRules',
        "l_3_firewall_rules":'l3FirewallRules',
        "l_7_firewall_rules":'l7FirewallRules'
    }

    def __init__(self,
                 settings=None,
                 traffic_shaping_rules=None,
                 l_3_firewall_rules=None,
                 l_7_firewall_rules=None):
        """Constructor for the FirewallAndTrafficShaping class"""

        # Initialize members of the class
        self.settings = settings
        self.traffic_shaping_rules = traffic_shaping_rules
        self.l_3_firewall_rules = l_3_firewall_rules
        self.l_7_firewall_rules = l_7_firewall_rules


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        settings = dictionary.get('settings')
        traffic_shaping_rules = None
        if dictionary.get('trafficShapingRules') != None:
            traffic_shaping_rules = list()
            for structure in dictionary.get('trafficShapingRules'):
                traffic_shaping_rules.append(test_meraki.models.traffic_shaping_rule.TrafficShapingRule.from_dictionary(structure))
        l_3_firewall_rules = None
        if dictionary.get('l3FirewallRules') != None:
            l_3_firewall_rules = list()
            for structure in dictionary.get('l3FirewallRules'):
                l_3_firewall_rules.append(test_meraki.models.l_3_firewall_rule.L3FirewallRule.from_dictionary(structure))
        l_7_firewall_rules = None
        if dictionary.get('l7FirewallRules') != None:
            l_7_firewall_rules = list()
            for structure in dictionary.get('l7FirewallRules'):
                l_7_firewall_rules.append(test_meraki.models.l_7_firewall_rule.L7FirewallRule.from_dictionary(structure))

        # Return an object of this model
        return cls(settings,
                   traffic_shaping_rules,
                   l_3_firewall_rules,
                   l_7_firewall_rules)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkFirewalledService(object):

    """Implementation of the 'updateNetworkFirewalledService' model.

    TODO: type model description here.

    Attributes:
        access (AccessEnum): A string indicating the rule for which IPs are
            allowed to use the specified service. Acceptable values are
            "blocked" (no remote IPs can access the service), "restricted"
            (only whitelisted IPs can access the service), and "unrestriced"
            (any remote IP can access the service). This field is required
        allowed_ips (list of string): An array of whitelisted IPs that can
            access the service. This field is required if "access" is set to
            "restricted". Otherwise this field is ignored

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "access":'access',
        "allowed_ips":'allowedIps'
    }

    def __init__(self,
                 access=None,
                 allowed_ips=None):
        """Constructor for the UpdateNetworkFirewalledService class"""

        # Initialize members of the class
        self.access = access
        self.allowed_ips = allowed_ips


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        access = dictionary.get('access')
        allowed_ips = dictionary.get('allowedIps')

        # Return an object of this model
        return cls(access,
                   allowed_ips)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkNetflowSettings(object):

    """Implementation of the 'updateNetworkNetflowSettings' model.

    TODO: type model description here.

    Attributes:
        reporting_enabled (bool): Boolean indicating whether NetFlow traffic
            reporting is enabled (true) or disabled (false).
        collector_ip (string): The IPv4 address of the NetFlow collector.
        collector_port (int): The port that the NetFlow collector will be
            listening on.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "reporting_enabled":'reportingEnabled',
        "collector_ip":'collectorIp',
        "collector_port":'collectorPort'
    }

    def __init__(self,
                 reporting_enabled=None,
                 collector_ip=None,
                 collector_port=None):
        """Constructor for the UpdateNetworkNetflowSettings class"""

        # Initialize members of the class
        self.reporting_enabled = reporting_enabled
        self.collector_ip = collector_ip
        self.collector_port = collector_port


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        reporting_enabled = dictionary.get('reportingEnabled')
        collector_ip = dictionary.get('collectorIp')
        collector_port = dictionary.get('collectorPort')

        # Return an object of this model
        return cls(reporting_enabled,
                   collector_ip,
                   collector_port)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Override(object):

    """Implementation of the 'Override' model.

    TODO: type model description here.

    Attributes:
        switches (list of string): List of switch serials. Applicable only for
            switch network.
        switch_profiles (list of string): List of switch profile IDs.
            Applicable only for template network.
        mtu_size (int): MTU size for the switches or switch profiles.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtu_size":'mtuSize',
        "switches":'switches',
        "switch_profiles":'switchProfiles'
    }

    def __init__(self,
                 mtu_size=None,
                 switches=None,
                 switch_profiles=None):
        """Constructor for the Override class"""

        # Initialize members of the class
        self.switches = switches
        self.switch_profiles = switch_profiles
        self.mtu_size = mtu_size


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mtu_size = dictionary.get('mtuSize')
        switches = dictionary.get('switches')
        switch_profiles = dictionary.get('switchProfiles')

        # Return an object of this model
        return cls(mtu_size,
                   switches,
                   switch_profiles)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.bandwidth_limits

class Bandwidth(object):

    """Implementation of the 'Bandwidth' model.

    The bandwidth settings for clients bound to your group policy.

    Attributes:
        settings (SettingsEnum): How bandwidth limits are enforced. Can be
            'network default', 'ignore' or 'custom'.
        bandwidth_limits (BandwidthLimits): The bandwidth limits object,
            specifying upload and download speed for clients bound to the
            group policy. These are only enforced if 'settings' is set to
            'custom'.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "settings":'settings',
        "bandwidth_limits":'bandwidthLimits'
    }

    def __init__(self,
                 settings=None,
                 bandwidth_limits=None):
        """Constructor for the Bandwidth class"""

        # Initialize members of the class
        self.settings = settings
        self.bandwidth_limits = bandwidth_limits


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        settings = dictionary.get('settings')
        bandwidth_limits = test_meraki.models.bandwidth_limits.BandwidthLimits.from_dictionary(dictionary.get('bandwidthLimits')) if dictionary.get('bandwidthLimits') else None

        # Return an object of this model
        return cls(settings,
                   bandwidth_limits)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ReservedIpRange(object):

    """Implementation of the 'ReservedIpRange' model.

    TODO: type model description here.

    Attributes:
        start (string): The first IP in the reserved range
        end (string): The last IP in the reserved range
        comment (string): A text comment for the reserved range

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "start":'start',
        "end":'end',
        "comment":'comment'
    }

    def __init__(self,
                 start=None,
                 end=None,
                 comment=None):
        """Constructor for the ReservedIpRange class"""

        # Initialize members of the class
        self.start = start
        self.end = end
        self.comment = comment


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        start = dictionary.get('start')
        end = dictionary.get('end')
        comment = dictionary.get('comment')

        # Return an object of this model
        return cls(start,
                   end,
                   comment)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class IpsecPolicies(object):

    """Implementation of the 'IpsecPolicies' model.

    Custom IPSec policies for the VPN peer. If not included and a preset has
    not been chosen, the default preset for IPSec policies will be used.

    Attributes:
        ike_cipher_algo (list of string): This is the cipher algorithm to be
            used in Phase 1. The value should be an array with one of the
            following algorithms: 'aes256', 'aes192', 'aes128', 'tripledes',
            'des'
        ike_auth_algo (list of string): This is the authentication algorithm
            to be used in Phase 1. The value should be an array with one of
            the following algorithms: 'sha1', 'md5'
        ike_diffie_hellman_group (list of string): This is the Diffie-Hellman
            group to be used in Phase 1. The value should be an array with one
            of the following algorithms: 'group5', 'group2', 'group1'
        ike_lifetime (int): The lifetime of the Phase 1 SA in seconds.
        child_cipher_algo (list of string): This is the cipher algorithms to
            be used in Phase 2. The value should be an array with one or more
            of the following algorithms: 'aes256', 'aes192', 'aes128',
            'tripledes', 'des', 'null'
        child_auth_algo (list of string): This is the authentication
            algorithms to be used in Phase 2. The value should be an array
            with one of the following algorithms: 'sha1', 'md5'
        child_pfs_group (list of string): This is the Diffie-Hellman group to
            be used for Perfect Forward Secrecy in Phase 2. The value should
            be an array with one of the following values: 'disabled',
            'group5', 'group2', 'group1'
        child_lifetime (int): The lifetime of the Phase 2 SA in seconds.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "ike_cipher_algo":'ikeCipherAlgo',
        "ike_auth_algo":'ikeAuthAlgo',
        "ike_diffie_hellman_group":'ikeDiffieHellmanGroup',
        "ike_lifetime":'ikeLifetime',
        "child_cipher_algo":'childCipherAlgo',
        "child_auth_algo":'childAuthAlgo',
        "child_pfs_group":'childPfsGroup',
        "child_lifetime":'childLifetime'
    }

    def __init__(self,
                 ike_cipher_algo=None,
                 ike_auth_algo=None,
                 ike_diffie_hellman_group=None,
                 ike_lifetime=None,
                 child_cipher_algo=None,
                 child_auth_algo=None,
                 child_pfs_group=None,
                 child_lifetime=None):
        """Constructor for the IpsecPolicies class"""

        # Initialize members of the class
        self.ike_cipher_algo = ike_cipher_algo
        self.ike_auth_algo = ike_auth_algo
        self.ike_diffie_hellman_group = ike_diffie_hellman_group
        self.ike_lifetime = ike_lifetime
        self.child_cipher_algo = child_cipher_algo
        self.child_auth_algo = child_auth_algo
        self.child_pfs_group = child_pfs_group
        self.child_lifetime = child_lifetime


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        ike_cipher_algo = dictionary.get('ikeCipherAlgo')
        ike_auth_algo = dictionary.get('ikeAuthAlgo')
        ike_diffie_hellman_group = dictionary.get('ikeDiffieHellmanGroup')
        ike_lifetime = dictionary.get('ikeLifetime')
        child_cipher_algo = dictionary.get('childCipherAlgo')
        child_auth_algo = dictionary.get('childAuthAlgo')
        child_pfs_group = dictionary.get('childPfsGroup')
        child_lifetime = dictionary.get('childLifetime')

        # Return an object of this model
        return cls(ike_cipher_algo,
                   ike_auth_algo,
                   ike_diffie_hellman_group,
                   ike_lifetime,
                   child_cipher_algo,
                   child_auth_algo,
                   child_pfs_group,
                   child_lifetime)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateOrganization(object):

    """Implementation of the 'updateOrganization' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the organization

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name'
    }

    def __init__(self,
                 name=None):
        """Constructor for the UpdateOrganization class"""

        # Initialize members of the class
        self.name = name


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')

        # Return an object of this model
        return cls(name)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CreateNetworkHttpServer(object):

    """Implementation of the 'createNetworkHttpServer' model.

    TODO: type model description here.

    Attributes:
        name (string): A name for easy reference to the HTTP server
        url (string): The URL of the HTTP server
        shared_secret (string): A shared secret that will be included in POSTs
            sent to the HTTP server. This secret can be used to verify that
            the request was sent by Meraki.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "url":'url',
        "shared_secret":'sharedSecret'
    }

    def __init__(self,
                 name=None,
                 url=None,
                 shared_secret=None):
        """Constructor for the CreateNetworkHttpServer class"""

        # Initialize members of the class
        self.name = name
        self.url = url
        self.shared_secret = shared_secret


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        url = dictionary.get('url')
        shared_secret = dictionary.get('sharedSecret')

        # Return an object of this model
        return cls(name,
                   url,
                   shared_secret)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.custom_pie_chart_item

class UpdateNetworkTrafficAnalysisSettings(object):

    """Implementation of the 'updateNetworkTrafficAnalysisSettings' model.

    TODO: type model description here.

    Attributes:
        mode (Mode1Enum): The traffic analysis mode for the network. Can be
            one of 'disabled' (do not collect traffic types),     'basic'
            (collect generic traffic categories), or 'detailed' (collect
            destination hostnames).
        custom_pie_chart_items (list of CustomPieChartItem): The list of items
            that make up the custom pie chart for traffic reporting.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mode":'mode',
        "custom_pie_chart_items":'customPieChartItems'
    }

    def __init__(self,
                 mode=None,
                 custom_pie_chart_items=None):
        """Constructor for the UpdateNetworkTrafficAnalysisSettings class"""

        # Initialize members of the class
        self.mode = mode
        self.custom_pie_chart_items = custom_pie_chart_items


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mode = dictionary.get('mode')
        custom_pie_chart_items = None
        if dictionary.get('customPieChartItems') != None:
            custom_pie_chart_items = list()
            for structure in dictionary.get('customPieChartItems'):
                custom_pie_chart_items.append(test_meraki.models.custom_pie_chart_item.CustomPieChartItem.from_dictionary(structure))

        # Return an object of this model
        return cls(mode,
                   custom_pie_chart_items)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Rule6(object):

    """Implementation of the 'Rule6' model.

    TODO: type model description here.

    Attributes:
        name (string): A descriptive name for the rule
        public_ip (string): The IP address that will be used to access the
            internal resource from the WAN
        lan_ip (string): The IP address of the server or device that hosts the
            internal resource that you wish to make available on the WAN
        uplink (string): The physical WAN interface on which the traffic will
            arrive ('internet1' or, if available, 'internet2')
        allowed_inbound (list of object): The ports this mapping will provide
            access on, and the remote IPs that will be allowed access to the
            resource
        protocol (string): Either of the following: 'tcp', 'udp', 'icmp-ping'
            or 'any'
        destination_ports (string): An array of ports or port ranges that will
            be forwarded to the host on the LAN
        allowed_ips (string): An array of ranges of WAN IP addresses that are
            allowed to make inbound connections on the specified ports or port
            ranges, or 'any'

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "public_ip":'publicIp',
        "lan_ip":'lanIp',
        "uplink":'uplink',
        "allowed_inbound":'allowedInbound',
        "protocol":'protocol',
        "destination_ports":'destinationPorts',
        "allowed_ips":'allowedIps'
    }

    def __init__(self,
                 name=None,
                 public_ip=None,
                 lan_ip=None,
                 uplink=None,
                 allowed_inbound=None,
                 protocol=None,
                 destination_ports=None,
                 allowed_ips=None):
        """Constructor for the Rule6 class"""

        # Initialize members of the class
        self.name = name
        self.public_ip = public_ip
        self.lan_ip = lan_ip
        self.uplink = uplink
        self.allowed_inbound = allowed_inbound
        self.protocol = protocol
        self.destination_ports = destination_ports
        self.allowed_ips = allowed_ips


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        public_ip = dictionary.get('publicIp')
        lan_ip = dictionary.get('lanIp')
        uplink = dictionary.get('uplink')
        allowed_inbound = dictionary.get('allowedInbound')
        protocol = dictionary.get('protocol')
        destination_ports = dictionary.get('destinationPorts')
        allowed_ips = dictionary.get('allowedIps')

        # Return an object of this model
        return cls(name,
                   public_ip,
                   lan_ip,
                   uplink,
                   allowed_inbound,
                   protocol,
                   destination_ports,
                   allowed_ips)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class SecurityEventsController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network_client_security_events(self,
                                           network_id,
                                           client_id,
                                           t_0=None,
                                           t_1=None,
                                           timespan=None,
                                           per_page=None,
                                           starting_after=None,
                                           ending_before=None):
        """Does a GET request to /networks/{networkId}/clients/{clientId}/securityEvents.

        List the security events for a client. Clients can be identified by a
        client key or either the MAC or IP depending on whether the network
        uses Track-by-IP.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 791 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 791 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 791 days. The default is 31 days.
            per_page (int, optional): The number of entries per page returned.
                Acceptable range is 3 - 1000. Default is 100.
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/securityEvents'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_security_events(self,
                                    network_id,
                                    t_0=None,
                                    t_1=None,
                                    timespan=None,
                                    per_page=None,
                                    starting_after=None,
                                    ending_before=None):
        """Does a GET request to /networks/{networkId}/securityEvents.

        List the security events for a network

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 365 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 365 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 365 days. The default is 31 days.
            per_page (int, optional): The number of entries per page returned.
                Acceptable range is 3 - 1000. Default is 100.
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/securityEvents'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_organization_security_events(self,
                                         organization_id,
                                         t_0=None,
                                         t_1=None,
                                         timespan=None,
                                         per_page=None,
                                         starting_after=None,
                                         ending_before=None):
        """Does a GET request to /organizations/{organizationId}/securityEvents.

        List the security events for an organization

        Args:
            organization_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 365 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 365 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 365 days. The default is 31 days.
            per_page (int, optional): The number of entries per page returned.
                Acceptable range is 3 - 1000. Default is 100.
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/securityEvents'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



__all__ = [
    'base_controller',
    'api_usage_controller',
    'action_batches_controller',
    'admins_controller',
    'alert_settings_controller',
    'bluetooth_clients_controller',
    'cameras_controller',
    'clients_controller',
    'config_templates_controller',
    'connectivity_monitoring_destinations_controller',
    'content_filtering_categories_controller',
    'content_filtering_rules_controller',
    'dashboard_branding_policies_controller',
    'devices_controller',
    'events_controller',
    'firewalled_services_controller',
    'floorplans_controller',
    'group_policies_controller',
    'http_servers_controller',
    'intrusion_settings_controller',
    'licenses_controller',
    'mrl_3_firewall_controller',
    'mv_sense_controller',
    'mx_11_nat_rules_controller',
    'mx_1_many_nat_rules_controller',
    'mxl_3_firewall_controller',
    'mxl_7_application_categories_controller',
    'mxl_7_firewall_controller',
    'mxvlan_ports_controller',
    'mxvpn_firewall_controller',
    'mx_cellular_firewall_controller',
    'mx_port_forwarding_rules_controller',
    'mx_static_routes_controller',
    'mx_warm_spare_settings_controller',
    'malware_settings_controller',
    'management_interface_settings_controller',
    'meraki_auth_users_controller',
    'named_tag_scope_controller',
    'net_flow_settings_controller',
    'networks_controller',
    'open_api_spec_controller',
    'organizations_controller',
    'pii_controller',
    'radio_settings_controller',
    'saml_roles_controller',
    'sm_controller',
    'snmp_settings_controller',
    'ssi_ds_controller',
    'security_events_controller',
    'splash_login_attempts_controller',
    'splash_settings_controller',
    'switch_ac_ls_controller',
    'switch_port_schedules_controller',
    'switch_ports_controller',
    'switch_profiles_controller',
    'switch_settings_controller',
    'switch_stacks_controller',
    'syslog_servers_controller',
    'traffic_analysis_settings_controller',
    'traffic_shaping_controller',
    'uplink_settings_controller',
    'vla_ns_controller',
    'webhook_logs_controller',
    'wireless_health_controller',
    'wireless_settings_controller',
]


# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class AssignOrganizationLicensesSeats(object):

    """Implementation of the 'assignOrganizationLicensesSeats' model.

    TODO: type model description here.

    Attributes:
        license_id (string): The ID of the SM license to assign seats from
        network_id (string): The ID of the SM network to assign the seats to
        seat_count (int): The number of seats to assign to the SM network.
            Must be less than or equal to the total number of seats of the
            license

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "license_id":'licenseId',
        "network_id":'networkId',
        "seat_count":'seatCount'
    }

    def __init__(self,
                 license_id=None,
                 network_id=None,
                 seat_count=None):
        """Constructor for the AssignOrganizationLicensesSeats class"""

        # Initialize members of the class
        self.license_id = license_id
        self.network_id = network_id
        self.seat_count = seat_count


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        license_id = dictionary.get('licenseId')
        network_id = dictionary.get('networkId')
        seat_count = dictionary.get('seatCount')

        # Return an object of this model
        return cls(license_id,
                   network_id,
                   seat_count)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ProvisionNetworkClients(object):

    """Implementation of the 'provisionNetworkClients' model.

    TODO: type model description here.

    Attributes:
        mac (string): The MAC address of the client. Required.
        name (string): The display name for the client. Optional. Limited to
            255 bytes.
        device_policy (string): The policy to apply to the specified client.
            Can be 'Whitelisted', 'Blocked', 'Normal' or 'Group policy'.
            Required.
        group_policy_id (string): The ID of the desired group policy to apply
            to the client. Required if 'devicePolicy' is set to "Group
            policy". Otherwise this is ignored.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mac":'mac',
        "name":'name',
        "device_policy":'devicePolicy',
        "group_policy_id":'groupPolicyId'
    }

    def __init__(self,
                 mac=None,
                 name=None,
                 device_policy=None,
                 group_policy_id=None):
        """Constructor for the ProvisionNetworkClients class"""

        # Initialize members of the class
        self.mac = mac
        self.name = name
        self.device_policy = device_policy
        self.group_policy_id = group_policy_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mac = dictionary.get('mac')
        name = dictionary.get('name')
        device_policy = dictionary.get('devicePolicy')
        group_policy_id = dictionary.get('groupPolicyId')

        # Return an object of this model
        return cls(mac,
                   name,
                   device_policy,
                   group_policy_id)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Rule7(object):

    """Implementation of the 'Rule7' model.

    TODO: type model description here.

    Attributes:
        name (string): A descriptive name for the rule
        lan_ip (string): The IP address of the server or device that hosts the
            internal resource that you wish to make available on the WAN
        uplink (string): The physical WAN interface on which the traffic will
            arrive ('internet1' or, if available, 'internet2' or 'both')
        public_port (string): A port or port ranges that will be forwarded to
            the host on the LAN
        local_port (string): A port or port ranges that will receive the
            forwarded traffic from the WAN
        allowed_ips (list of string): An array of ranges of WAN IP addresses
            that are allowed to make inbound connections on the specified
            ports or port ranges (or any)
        protocol (string): TCP or UDP

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "lan_ip":'lanIp',
        "uplink":'uplink',
        "public_port":'publicPort',
        "local_port":'localPort',
        "allowed_ips":'allowedIps',
        "protocol":'protocol'
    }

    def __init__(self,
                 name=None,
                 lan_ip=None,
                 uplink=None,
                 public_port=None,
                 local_port=None,
                 allowed_ips=None,
                 protocol=None):
        """Constructor for the Rule7 class"""

        # Initialize members of the class
        self.name = name
        self.lan_ip = lan_ip
        self.uplink = uplink
        self.public_port = public_port
        self.local_port = local_port
        self.allowed_ips = allowed_ips
        self.protocol = protocol


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        lan_ip = dictionary.get('lanIp')
        uplink = dictionary.get('uplink')
        public_port = dictionary.get('publicPort')
        local_port = dictionary.get('localPort')
        allowed_ips = dictionary.get('allowedIps')
        protocol = dictionary.get('protocol')

        # Return an object of this model
        return cls(name,
                   lan_ip,
                   uplink,
                   public_port,
                   local_port,
                   allowed_ips,
                   protocol)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkSmTargetGroup(object):

    """Implementation of the 'updateNetworkSmTargetGroup' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of this target group
        scope (string): The scope and tag options of the target group. Comma
            separated values beginning with one of withAny, withAll,
            withoutAny, withoutAll, all, none, followed by tags. Default to
            none if empty.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "scope":'scope'
    }

    def __init__(self,
                 name=None,
                 scope=None):
        """Constructor for the UpdateNetworkSmTargetGroup class"""

        # Initialize members of the class
        self.name = name
        self.scope = scope


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        scope = dictionary.get('scope')

        # Return an object of this model
        return cls(name,
                   scope)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class IpVersionEnum(object):

    """Implementation of the 'IpVersion' enum.

    IP address version (must be 'any', 'ipv4' or 'ipv6'). Applicable only if
    network supports IPv6. Default value is 'ipv4'.

    Attributes:
        ANY: TODO: type description here.
        IPV4: TODO: type description here.
        IPV6: TODO: type description here.

    """

    ANY = 'any'

    IPV4 = 'ipv4'

    IPV6 = 'ipv6'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkWirelessSettings(object):

    """Implementation of the 'updateNetworkWirelessSettings' model.

    TODO: type model description here.

    Attributes:
        meshing_enabled (bool): Toggle for enabling or disabling meshing in a
            network
        ipv_6_bridge_enabled (bool): Toggle for enabling or disabling IPv6
            bridging in a network (Note: if enabled, SSIDs must also be
            configured to use bridge mode)
        location_analytics_enabled (bool): Toggle for enabling or disabling
            location analytics for your network

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "meshing_enabled":'meshingEnabled',
        "ipv_6_bridge_enabled":'ipv6BridgeEnabled',
        "location_analytics_enabled":'locationAnalyticsEnabled'
    }

    def __init__(self,
                 meshing_enabled=None,
                 ipv_6_bridge_enabled=None,
                 location_analytics_enabled=None):
        """Constructor for the UpdateNetworkWirelessSettings class"""

        # Initialize members of the class
        self.meshing_enabled = meshing_enabled
        self.ipv_6_bridge_enabled = ipv_6_bridge_enabled
        self.location_analytics_enabled = location_analytics_enabled


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        meshing_enabled = dictionary.get('meshingEnabled')
        ipv_6_bridge_enabled = dictionary.get('ipv6BridgeEnabled')
        location_analytics_enabled = dictionary.get('locationAnalyticsEnabled')

        # Return an object of this model
        return cls(meshing_enabled,
                   ipv_6_bridge_enabled,
                   location_analytics_enabled)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class UplinkEnum(object):

    """Implementation of the 'uplink' enum.

    TODO: type enum description here.

    Attributes:
        WAN1: TODO: type description here.
        WAN2: TODO: type description here.
        CELLULAR: TODO: type description here.

    """

    WAN1 = 'wan1'

    WAN2 = 'wan2'

    CELLULAR = 'cellular'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ModeEnum(object):

    """Implementation of the 'Mode' enum.

    The site-to-site VPN mode. Can be one of 'none', 'spoke' or 'hub'

    Attributes:
        NONE: TODO: type description here.
        SPOKE: TODO: type description here.
        HUB: TODO: type description here.

    """

    NONE = 'none'

    SPOKE = 'spoke'

    HUB = 'hub'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Destination(object):

    """Implementation of the 'Destination' model.

    TODO: type model description here.

    Attributes:
        ip (string): The IP address to test connectivity with
        description (string): Description of the testing destination.
            Optional, defaults to null
        default (bool): Boolean indicating whether this is the default testing
            destination (true) or not (false). Defaults to false. Only one
            default is allowed

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "ip":'ip',
        "description":'description',
        "default":'default'
    }

    def __init__(self,
                 ip=None,
                 description=None,
                 default=None):
        """Constructor for the Destination class"""

        # Initialize members of the class
        self.ip = ip
        self.description = description
        self.default = default


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        ip = dictionary.get('ip')
        description = dictionary.get('description')
        default = dictionary.get('default')

        # Return an object of this model
        return cls(ip,
                   description,
                   default)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Policy6Enum(object):

    """Implementation of the 'Policy6' enum.

    'allow' or 'deny' traffic specified by this rule.

    Attributes:
        ALLOW: TODO: type description here.
        DENY: TODO: type description here.

    """

    ALLOW = 'allow'

    DENY = 'deny'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class WanEnabledEnum(object):

    """Implementation of the 'WanEnabled' enum.

    Enable or disable the interface (only for MX devices). Valid values are
    'enabled', 'disabled', and 'not configured'.

    Attributes:
        ENABLED: TODO: type description here.
        DISABLED: TODO: type description here.
        ENUM_NOT CONFIGURED: TODO: type description here.

    """

    ENABLED = 'enabled'

    DISABLED = 'disabled'

    ENUM_NOT_CONFIGURED = 'not configured'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Action(object):

    """Implementation of the 'Action' model.

    TODO: type model description here.

    Attributes:
        resource (string): Unique identifier for the resource to be acted on
        operation (string): The operation to be used
        body (object): The body of the action

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "resource":'resource',
        "operation":'operation',
        "body":'body'
    }

    def __init__(self,
                 resource=None,
                 operation=None,
                 body=None):
        """Constructor for the Action class"""

        # Initialize members of the class
        self.resource = resource
        self.operation = operation
        self.body = body


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        resource = dictionary.get('resource')
        operation = dictionary.get('operation')
        body = dictionary.get('body')

        # Return an object of this model
        return cls(resource,
                   operation,
                   body)


